==> reakit-system-bootstrap-0.6.3.tgz: package/es/Menu.js <==
import { _ as _objectSpread2, b as _objectWithoutPropertiesLoose, a as _taggedTemplateLiteralLoose } from './_rollupPluginBabelHelpers-a01c5bdc.js';
import { css, cx } from 'emotion';
import { useDarken } from 'reakit-system-palette/utils/darken';
import { useContrast } from 'reakit-system-palette/utils/contrast';
import { usePalette } from 'reakit-system-palette/utils/palette';
import { createElement, cloneElement, Fragment } from 'react';

function _templateObject9() {
  var data = _taggedTemplateLiteralLoose(["\n    display: inherit;\n    flex-direction: inherit;\n  "]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n    outline: 0;\n\n    &[aria-checked=\"true\"] {\n      &:before {\n        content: \"\u2022\";\n        position: absolute;\n        font-size: 1.4em;\n        top: -0.25em;\n        left: 0.35em;\n        width: 0.7142857143em;\n        height: 0.7142857143em;\n      }\n    }\n  "]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n    outline: 0;\n\n    &[aria-checked=\"true\"] {\n      &:before {\n        content: \"\u2713\";\n        position: absolute;\n        top: 0;\n        left: 0.4em;\n        width: 1em;\n        height: 1em;\n      }\n    }\n  "]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteralLoose(["\n          margin-", ": 0.5em;\n        "]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5() {
  var data = _taggedTemplateLiteralLoose(["\n          padding-right: 2em !important;\n        "]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n\n    [role=\"menu\"] > & {\n      ", "\n    }\n\n    svg {\n      fill: currentColor;\n      width: 0.65em;\n      height: 0.65em;\n\n      [role=\"menu\"] > & {\n        position: absolute;\n        top: 50%;\n        transform: translateY(-50%);\n        ", ": 0.5em;\n      }\n\n      [role=\"menubar\"] > & {\n        display: none;\n      }\n\n      ", "\n    }\n  "]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteralLoose(["\n    display: flex;\n    border-radius: 0;\n\n    &:not([aria-orientation=\"horizontal\"]) > &[aria-orientation=\"vertical\"] {\n      margin-top: -0.3em;\n    }\n  "]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteralLoose(["\n    &&& {\n      line-height: 1.5;\n      padding: 0 ", ";\n      text-align: left;\n      justify-content: flex-start;\n      border: 0;\n      border-radius: 0;\n      font-size: 100%;\n      background: transparent;\n      color: ", ";\n      margin: 0;\n      user-select: none;\n      cursor: default;\n      text-decoration: none;\n\n      &:focus,\n      &[aria-expanded=\"true\"] {\n        background-color: ", ";\n        color: ", ";\n        box-shadow: none !important;\n      }\n\n      &:active {\n        background-color: ", " !important;\n      }\n    }\n  "]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n    display: flex;\n    flex-direction: ", ";\n    white-space: nowrap;\n    box-shadow: none !important;\n\n    &[aria-orientation=\"vertical\"] {\n      padding: 0.25em 0;\n    }\n\n    &[aria-orientation=\"horizontal\"] {\n      padding: 0;\n    }\n  "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
function useStaticMenuProps(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var isHorizontal = options.orientation === "horizontal";
  var staticMenu = css(_templateObject(), isHorizontal ? "row" : "column");
  return _objectSpread2({}, htmlProps, {
    className: cx(staticMenu, htmlProps.className)
  });
}
function useMenuItemProps(_ref, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var unstable_system = _ref.unstable_system,
      options = _objectWithoutPropertiesLoose(_ref, ["unstable_system"]);

  var foreground = usePalette("foreground") || "black";
  var primary = usePalette("primary") || "blue";
  var primaryContrast = useContrast(primary);
  var darkPrimary = useDarken(primary, 0.2);
  var isHorizontal = options.orientation === "horizontal";
  var menuItem = css(_templateObject2(), isHorizontal ? "0.5em" : "1.5em", foreground, primary, primaryContrast, darkPrimary);
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItem, htmlProps.className)
  });
}
function useMenuOptions(_ref2) {
  var _ref2$unstable_system = _ref2.unstable_system;
  _ref2$unstable_system = _ref2$unstable_system === void 0 ? {} : _ref2$unstable_system;

  var _ref2$unstable_system2 = _ref2$unstable_system.palette,
      palette = _ref2$unstable_system2 === void 0 ? "background" : _ref2$unstable_system2,
      _ref2$unstable_system3 = _ref2$unstable_system.fill,
      fill = _ref2$unstable_system3 === void 0 ? "opaque" : _ref2$unstable_system3,
      system = _objectWithoutPropertiesLoose(_ref2$unstable_system, ["palette", "fill"]),
      options = _objectWithoutPropertiesLoose(_ref2, ["unstable_system"]);

  return _objectSpread2({
    unstable_system: _objectSpread2({
      palette: palette,
      fill: fill
    }, system)
  }, options);
}
function useMenuProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menu = css(_templateObject3());
  return _objectSpread2({}, htmlProps, {
    className: cx(menu, htmlProps.className)
  });
}
function useMenuDisclosureProps(options, _ref3) {
  if (_ref3 === void 0) {
    _ref3 = {};
  }

  var _ref4 = _ref3,
      children = _ref4.children,
      htmlProps = _objectWithoutPropertiesLoose(_ref4, ["children"]);

  var placement = options.unstable_originalPlacement || options.placement;
  var dir = placement ? placement.split("-")[0] : undefined;
  var svg = dir ? {
    top: createElement("svg", {
      viewBox: "0 0 50 43.3"
    }, createElement("polygon", {
      points: "25 0 0 43.3 50 43.3 25 0"
    })),
    bottom: createElement("svg", {
      viewBox: "0 0 50 43.3"
    }, createElement("polygon", {
      points: "25 43.3 50 0 0 0 25 43.3"
    })),
    right: createElement("svg", {
      viewBox: "0 0 43.3 50"
    }, createElement("polygon", {
      points: "43.3 25 0 0 0 50 43.3 25"
    })),
    left: createElement("svg", {
      viewBox: "0 0 43.3 50"
    }, createElement("polygon", {
      points: "0 25 43.3 50 43.3 0 0 25"
    }))
  }[dir] : null;
  var menuDisclosure = css(_templateObject4(), children && dir !== "left" && css(_templateObject5()), dir === "left" ? "left" : "right", children && css(_templateObject6(), dir === "left" ? "right" : "left"));
  return _objectSpread2({}, htmlProps, {
    children: typeof children === "function" ? function (props) {
      var child = children(props);
      return cloneElement(child, {
        children: createElement(Fragment, null, child.props.children, svg)
      });
    } : createElement(Fragment, null, children, svg),
    className: cx(menuDisclosure, htmlProps.className)
  });
}
function useMenuItemCheckboxProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuItemCheckbox = css(_templateObject7());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItemCheckbox, htmlProps.className)
  });
}
function useMenuItemRadioProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuItemRadio = css(_templateObject8());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItemRadio, htmlProps.className)
  });
}
function useMenuGroupProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuGroup = css(_templateObject9());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuGroup, htmlProps.className)
  });
}

export { useMenuDisclosureProps, useMenuGroupProps, useMenuItemCheckboxProps, useMenuItemProps, useMenuItemRadioProps, useMenuOptions, useMenuProps, useStaticMenuProps };

==> reakit-system-bootstrap-0.6.7.tgz: package/es/Menu.js <==
import { _ as _objectSpread2, b as _objectWithoutPropertiesLoose, a as _taggedTemplateLiteralLoose } from './_rollupPluginBabelHelpers-1b936d68.js';
import { css, cx } from 'emotion';
import { useDarken } from 'reakit-system-palette/utils/darken';
import { useContrast } from 'reakit-system-palette/utils/contrast';
import { usePalette } from 'reakit-system-palette/utils/palette';
import { createElement, cloneElement, Fragment } from 'react';

function _templateObject9() {
  var data = _taggedTemplateLiteralLoose(["\n    display: inherit;\n    flex-direction: inherit;\n  "]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n    outline: 0;\n\n    &[aria-checked=\"true\"] {\n      &:before {\n        content: \"\u2022\";\n        position: absolute;\n        font-size: 1.4em;\n        top: -0.25em;\n        left: 0.35em;\n        width: 0.7142857143em;\n        height: 0.7142857143em;\n      }\n    }\n  "]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n    outline: 0;\n\n    &[aria-checked=\"true\"] {\n      &:before {\n        content: \"\u2713\";\n        position: absolute;\n        top: 0;\n        left: 0.4em;\n        width: 1em;\n        height: 1em;\n      }\n    }\n  "]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteralLoose(["\n          margin-", ": 0.5em;\n        "]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5() {
  var data = _taggedTemplateLiteralLoose(["\n          padding-right: 2em !important;\n        "]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4() {
  var data = _taggedTemplateLiteralLoose(["\n    position: relative;\n\n    [role=\"menu\"] > & {\n      ", "\n    }\n\n    svg {\n      fill: currentColor;\n      width: 0.65em;\n      height: 0.65em;\n\n      [role=\"menu\"] > & {\n        position: absolute;\n        top: 50%;\n        transform: translateY(-50%);\n        ", ": 0.5em;\n      }\n\n      [role=\"menubar\"] > & {\n        display: none;\n      }\n\n      ", "\n    }\n  "]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteralLoose(["\n    display: flex;\n    border-radius: 0;\n\n    &:not([aria-orientation=\"horizontal\"]) > &[aria-orientation=\"vertical\"] {\n      margin-top: -0.3em;\n    }\n  "]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteralLoose(["\n    &&& {\n      line-height: 1.5;\n      padding: 0 ", ";\n      text-align: left;\n      justify-content: flex-start;\n      border: 0;\n      border-radius: 0;\n      font-size: 100%;\n      background: transparent;\n      color: ", ";\n      margin: 0;\n      user-select: none;\n      cursor: default;\n      text-decoration: none;\n\n      &:focus,\n      &[aria-expanded=\"true\"] {\n        background-color: ", ";\n        color: ", ";\n        box-shadow: none !important;\n      }\n\n      &:active {\n        background-color: ", " !important;\n      }\n    }\n  "]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n    display: flex;\n    flex-direction: ", ";\n    white-space: nowrap;\n    box-shadow: none !important;\n\n    &[aria-orientation=\"vertical\"] {\n      padding: 0.25em 0;\n    }\n\n    &[aria-orientation=\"horizontal\"] {\n      padding: 0;\n    }\n  "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
function useMenuBarProps(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var isHorizontal = options.orientation === "horizontal";
  var menuBar = css(_templateObject(), isHorizontal ? "row" : "column");
  return _objectSpread2({}, htmlProps, {
    className: cx(menuBar, htmlProps.className)
  });
}
function useMenuItemProps(_ref, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var unstable_system = _ref.unstable_system,
      options = _objectWithoutPropertiesLoose(_ref, ["unstable_system"]);

  var foreground = usePalette("foreground") || "black";
  var primary = usePalette("primary") || "blue";
  var primaryContrast = useContrast(primary);
  var darkPrimary = useDarken(primary, 0.2);
  var isHorizontal = options.orientation === "horizontal";
  var menuItem = css(_templateObject2(), isHorizontal ? "0.5em" : "1.5em", foreground, primary, primaryContrast, darkPrimary);
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItem, htmlProps.className)
  });
}
function useMenuOptions(_ref2) {
  var _ref2$unstable_system = _ref2.unstable_system;
  _ref2$unstable_system = _ref2$unstable_system === void 0 ? {} : _ref2$unstable_system;

  var _ref2$unstable_system2 = _ref2$unstable_system.palette,
      palette = _ref2$unstable_system2 === void 0 ? "background" : _ref2$unstable_system2,
      _ref2$unstable_system3 = _ref2$unstable_system.fill,
      fill = _ref2$unstable_system3 === void 0 ? "opaque" : _ref2$unstable_system3,
      system = _objectWithoutPropertiesLoose(_ref2$unstable_system, ["palette", "fill"]),
      options = _objectWithoutPropertiesLoose(_ref2, ["unstable_system"]);

  return _objectSpread2({
    unstable_system: _objectSpread2({
      palette: palette,
      fill: fill
    }, system)
  }, options);
}
function useMenuProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menu = css(_templateObject3());
  return _objectSpread2({}, htmlProps, {
    className: cx(menu, htmlProps.className)
  });
}
function useMenuDisclosureProps(options, _ref3) {
  if (_ref3 === void 0) {
    _ref3 = {};
  }

  var _ref4 = _ref3,
      children = _ref4.children,
      htmlProps = _objectWithoutPropertiesLoose(_ref4, ["children"]);

  var placement = options.unstable_originalPlacement || options.placement;
  var dir = placement ? placement.split("-")[0] : undefined;
  var svg = dir ? {
    top: createElement("svg", {
      viewBox: "0 0 50 43.3"
    }, createElement("polygon", {
      points: "25 0 0 43.3 50 43.3 25 0"
    })),
    bottom: createElement("svg", {
      viewBox: "0 0 50 43.3"
    }, createElement("polygon", {
      points: "25 43.3 50 0 0 0 25 43.3"
    })),
    right: createElement("svg", {
      viewBox: "0 0 43.3 50"
    }, createElement("polygon", {
      points: "43.3 25 0 0 0 50 43.3 25"
    })),
    left: createElement("svg", {
      viewBox: "0 0 43.3 50"
    }, createElement("polygon", {
      points: "0 25 43.3 50 43.3 0 0 25"
    }))
  }[dir] : null;
  var menuDisclosure = css(_templateObject4(), children && dir !== "left" && css(_templateObject5()), dir === "left" ? "left" : "right", children && css(_templateObject6(), dir === "left" ? "right" : "left"));
  return _objectSpread2({}, htmlProps, {
    children: typeof children === "function" ? function (props) {
      var child = children(props);
      return cloneElement(child, {
        children: createElement(Fragment, null, child.props.children, svg)
      });
    } : createElement(Fragment, null, children, svg),
    className: cx(menuDisclosure, htmlProps.className)
  });
}
function useMenuItemCheckboxProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuItemCheckbox = css(_templateObject7());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItemCheckbox, htmlProps.className)
  });
}
function useMenuItemRadioProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuItemRadio = css(_templateObject8());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuItemRadio, htmlProps.className)
  });
}
function useMenuGroupProps(_, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var menuGroup = css(_templateObject9());
  return _objectSpread2({}, htmlProps, {
    className: cx(menuGroup, htmlProps.className)
  });
}

export { useMenuBarProps, useMenuDisclosureProps, useMenuGroupProps, useMenuItemCheckboxProps, useMenuItemProps, useMenuItemRadioProps, useMenuOptions, useMenuProps };
